package com.pj.project.tb_driver;

import java.util.List;

import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_driver -- 司机
 *
 * @author qzy
 */
@RestController(value = "司机管理接口")
@RequestMapping("/TbDriver/")
public class TbDriverController {

    /**
     * 底层 Service 对象
     */
    @Autowired
    TbDriverService tbDriverService;

    /**
     * 增
     */
    @RequestMapping(value="add",name = "添加司机")
    @SaCheckPermission(TbDriver.PERMISSION_CODE_ADD)
    public AjaxJson add(TbDriver t) {
        tbDriverService.add(t);
        t = tbDriverService.getById(SP.publicMapper.getPrimarykey());
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 删
     */
    @RequestMapping("delete")
    @SaCheckPermission(TbDriver.PERMISSION_CODE_DEL)
    public AjaxJson delete(Long id) {
        tbDriverService.delete(id);
        return AjaxJson.getSuccess();
    }

    /**
     * 删 - 根据id列表
     */
    @RequestMapping("deleteByIds")
    @SaCheckPermission(TbDriver.PERMISSION_CODE_DEL)
    public AjaxJson deleteByIds() {
        List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
        int line = SP.publicMapper.deleteByIds(TbDriver.TABLE_NAME, ids);
        return AjaxJson.getByLine(line);
    }

    /**
     * 改
     */
    @RequestMapping("update")
    @SaCheckPermission(TbDriver.PERMISSION_CODE_EDIT)
    public AjaxJson update(TbDriver t) {
        tbDriverService.update(t);
        return AjaxJson.getSuccess();
    }

    /**
     * 查 - 根据id
     */
    @RequestMapping("getById")
    @SaCheckPermission(TbDriver.PERMISSION_CODE)
    public AjaxJson getById(Long id) {
        TbDriver t = tbDriverService.getById(id);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    @RequestMapping("getList")
    @SaCheckPermission(TbDriver.PERMISSION_CODE)
    public AjaxJson getList() {
        SoMap so = SoMap.getRequestSoMap();
        so.set("deleteStatus", 1);
        List<TbDriver> list = tbDriverService.getList(so.startPage());
        return AjaxJson.getPageData(so.getDataCount(), list);
    }


}
